// Demo:          Plot für Troposphärenkorrekturen
//
// Voraussetzung: GEOphyslib muß geladen sein
//
// Copyright (c) area7/Christof Schulze  2007
//--------------------------------------------------------------

format("e", 16); // mtlb_format("long")

if ~isdef('tropKor') then
  mprintf("\n--- Demo: plot_tropKor abgebrochen - Die Bibliothek GEOphyslib ist nicht geladen.\n");
  abort;
end;

mprintf("\n--- Demo: plot_tropKor ausgeführt.\n");

// Auswahl des relevanten Zenitwinkel
zenit = 0:80;

hk = 923.8326310534;  // Kr01
he = 1692.3132710429; // ES03

trop1 = matrix(tropKor_sm((zenit*%pi/180), he), 1, -1);
trop2 = matrix(tropKor_sm((zenit*%pi/180), hk), 1, -1);

// Plot erstellen
set("figure_style","new");
plot2d(zenit,[trop1',trop2'],[1, 2]);  
set(gca(),"auto_clear","off");

// Linienstile festlegen
e=gce();
e.children(1).thickness=2;
e.children(1).line_style=2;
e.children(2).thickness=2;

xtitle( 'Test der trop. Korrektur', 'Zenitwinkel [°]', 'trop. Korrektur [m]' );
hl=legend(['für ES03 (ell. Höhe 1692 m)';'für Kr01 (ell. Höhe 924 m)'],a=2);
set(gca(),"auto_clear","on");

format('v', 10);
clear hk he m n i trop1 trop2 zenit e hl legend gca gce;
