function [tangle]=atan2(yin,xin) 
// geodaetic arctan(y/x) in the interval (0, 2*pi), see also atan()
//
// in : yin, xin   - x- and y-value
//          
// out: tangle   - Richtungswinkel
//
// matrixfähig
// Copyright (c) area7/Christof Schulze  2008-2010
//--------------------------------------------------------------

// Number of arguments in function call
  [%nargout,%nargin] = argn(0);
  if (%nargin<>2) then
    err=39;
    error('Wrong number of input arguments:', err);
  end;

  xsize = size(xin); ysize = size(yin)
  if ~and(xsize==ysize) then
    err=60;
    error('Input arguments must have same size.', err);
  end;
  
  // Ouput variables initialisation (not found in input variables)
  tangle = zeros(size(xin,'*'));
  
  // compute for 1st quadrant only, take other quadrants and cardinal values 'manualy'
  xtemp = abs(xin); 
  ytemp = abs(yin); 
  
  
 // if ((xtemp<>0) & (ytemp<>0) & (ytemp*%eps)>xtemp) // we do not want 
 //   xtemp=ytemp*%eps;                              // division overflow
 // end

  // now for the quadrants
  k=find(xtemp<>0)
  if k<>[] then
    tangle(k) = atan(ytemp(k)./xtemp(k));  // 1:st quadrant
  end;
  
  k = find(yin>0 &xin==0);                // 1/2 pi
  if k<>[] then tangle(k)=%pi/2; end;

  k = find((yin>0) & (xin<0));            // 2:d quadrant
  if k<>[] then tangle(k)=%pi-tangle(k); end;

  k = find((yin==0) & (xin<0));           // pi
  if k<>[] then tangle(k)=%pi; end;

  k = find((yin<0) & (xin<0));            // 3:rd quadrant
  if k<>[] then tangle(k)=tangle(k)+%pi; end;

  k = find(yin<0 &xin==0);                // 3/2 pi
  if k<>[] then tangle(k)=3*%pi/2; end;

  k = find((yin<0) & (xin>0));            // 4:th quadrant
  if k<>[] then tangle(k)=2*%pi-tangle(k); end;
  
endfunction;