function [E]=unitVec(varargin)
// normierter Einheitsvektor eines Punktes in einem karthesischen Koordinatensystem
// 
// in1: Koordinatenmatrix [x1, y1, ....z1; x2, y2, ...z2]
//      Punktkoordinaten als Zeilenvektor
//
// in2: Liste von Koordinatenvektoren list([x1; y1; ...zn], [x2; y2; ... zn])
//      Punktkoordinagen alsSpaltenvektoren)
//
// out: Koordinatenmatrix (wie in1)
//      Koordinaten der normierten Einheitsvektoren als Zeilenvektor
//
// (matrixfhig)
//
// Copyright (c) area7/Christof Schulze  2008-2010
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
  E=[]; islist=%f;


// Number of arguments in function call
  [%nargout,%nargin] = argn(0);
  if (%nargin<1) then
    error('Fehler in Funktion unitVec(..). Zu wenige Eingabeparameter, mindestens ein Ellement mu angegeben werden.');
    break;
  else
    if (%nargin==1) then
      // Eingabeparameter ist eine Matrix
      mxin= varargin(1);
      islist=%f;
    else
      if ~compareVectors(varargin) then
        error('Fehler in Funktion unitVec(..). Eingabeparameter haben nicht die selbe Dimension');
        break;
      else
        islist=%t;
        for i=1:%nargin,
          mxin(:,i) = varargin(i);
        end;
        mxin = mxin';
      end;
    end;
  end;
  //disp(mxin);
  //disp('----------');

  mxin_sq = sqrt(sum(mxin.^2,'c'));

  //disp(mxin_sq);
  //disp('----------');

  for i=1:size(mxin_sq, 'r'),
    mxout(i,:) = mxin(i,:) ./ mxin_sq(i);
  end;

  //disp('out----------');

  E = mxout;      //E = [ eX eY eZ];

endfunction;
