function state = a7_svdata_init(newsatname)
// Initialisiert die Struktur zur Speicher der Satelitendaten
//          
// in:  argin - none - to create neu data structure
//              'newsatname' - to create the structure for one new SV
//
// out: state - Fehlercode wenn die Initialisierung nicht geklappt
//              hat, 0 wenn keine Fehler auftraten.
//
// Copyright (c) area7/Christof Schulze  2007-2011
//--------------------------------------------------------------
// private functions:
//  function state = a7_svname_exists(svname)
//  function svstruct = a7_svdata_createsv(svname)
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
state=0;

// Number of arguments in function call
  [%nargout,%nargin] = argn(0);
  if ~(%nargin == 1 | %nargin == 0)
    error('Scilib-GEO: Wrong number of input arguments');
    state=-1;
  end;  
   
// Werte zuweisen und ausgeben
  if (%nargin==0) then
    // Store neu anlegen oder löschen
    global a7_sv_store;
    a7_sv_store = list();
    global a7_sv_imported_files;
    a7_sv_imported_files = struct('sp3', list());
    state = 0;

  elseif (%nargin==1) then
    // add NEW SV data strukture
    svname=newsatname;
    //svname auf String überprüfen
    if ~(typeof(svname)=='string') then
      error('Scilib-GEO: Wrong type of input argument, only strings supported.');
      state=-1;
      return;
    end;
    //[TODO] auf Matrix überprüfen
    
    global a7_sv_store; 
      
    // [TODO] SV-Name auf doppelte überprüfen
    
    a7_sv_store($+1)= a7_svdata_createsv(svname)
                             
    state=0;
  end;
  
endfunction;

// ============================================================= private functions
function counter = a7_svname_exists(svname)
// chechs if svname already exists
//
// in : svname   - Name des SV das gefunden werden soll
//
// out: counter  - 0 wenn das SV nicht existiert,
//                 ansonsten Index des gesuchten SV
// -------------------------------------------------------------
counter=-1;

endfunction;

// ============================================================= private functions
function svstruct = a7_svdata_createsv(svname)
// generates a datastructure for a new Satelite
//
// in : svname   - Name des SV für den eine Struktur erzeugt werden soll
//
// out: svstruct - Strukt mit allen zum SV gehörenden Datenfeldern
// -------------------------------------------------------------
// Almanachdaten
// orbit type: 1= FIT (fitted)
//             2= EXT (extrapolated or predicted)
//             3= BCT (broadcast)
//             4= HLM (fitted after applying a Helmert transformation), [final]
//             0= calculated or not defined
//           +10= not trustworthy,  through errors in measurement, calculation or transmission
  almpos_fieldnames =      ['time(1:6)', 'type', ...
                            'x','y','z', 'sigma_x', 'sigma_y', 'sigma_z', ...
                            'delta_t', 'sigma_delta_t'];
  almpos_prec_fieldnames = ['time', 'type', 'value(RMS)'];
  almvel_fieldnames = [];
  almvel_prec_fieldnames = [];


  svstruct = struct('sv_name', svname, ...
                    'orbit_almpos_fieldnames', almpos_fieldnames, ...
                    'orbit_almpos_prec_fieldnames', almpos_prec_fieldnames, ...
                    'orbit_almvel_fieldnames', almvel_fieldnames, ...
                    'orbit_almpos', [], ...
                    'orbit_almpos_prec', [], ...
                    'orbit_almvel', []);
 
endfunction;