function [satsalm] = alm_parse_yumafile(yfile)
// Einlesen: Almanachdaten im Yuma-Format
//
// in : yfile: als Textstring vollständiger oder rel. Dateipfad, oder
//      als logische Einheit, wie sie von <i>mopen</i> gegeben wird.
//          
// out: .....
//
// Copyright (c) area7/Christof Schulze  2007-2010
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
  satsalm=[]; numsats=[];

  Yf = mgetl(yfile);  //  This is your input file

// A Yuma-file has 15 rows per satellite (including a final blank line), 
  numsats = int(size(Yf,1)/15);  // number of lines in the textfile, trimed with int to take care of possible final blanks
  satdata = ones(numsats, 12);

  for satno=1:numsats
 
    // see Scilab help for commands part and evstr
    linum = 15*(satno-1)+2; // each sat: 15 lines, start at 2, one empty line
    
    PRN = evstr(part(Yf(linum),28:46));       // ID: PRN of the SV
    health = evstr(part(Yf(linum+1),28:46));  // health: 000=good
    es = evstr(part(Yf(linum+2),28:46));      // Eccentricity: of SV orbit
    toa = evstr(part(Yf(linum+3),28:46));     // Time of Applicability [s]
    i0 = evstr(part(Yf(linum+4),28:46));      // Orb inclination [rad]
    omegadot = evstr(part(Yf(linum+5),28:46));// Rate right acsen [rad/s]
    sqrta = evstr(part(Yf(linum+6),28:46));   // [m^0.5]
    omega0 = evstr(part(Yf(linum+7),28:46));  // Right ascen at week [rad]
    w = evstr(part(Yf(linum+8),28:46));       // Arg of perigee [rad]
    m0 = evstr(part(Yf(linum+9),28:46));      // Mean anomaly [rad]
    af0 = evstr(part(Yf(linum+10),28:46));    // Af(0): SV clock bias [s]
    af1 = evstr(part(Yf(linum+11),28:46));    // Af(1): SV clock Drift [s/s] note: Af(2) = 0
    week = evstr(part(Yf(linum+12),28:46));   // week: GPS-week every 7 days since 22 Aug 1999

    satdata(satno,:) = [PRN, health, es, toa, i0, omegadot, sqrta, w, m0, af0, af1, week];

  end;
  satsalm = satdata;

endfunction;
