function deltaTrel = delta_t_rel(e, E_k, a)
// Funktion zur Berechnung der Satellitenuhrkorrektur wegen des
// relativistischen Effekts durch die Bahnschwankungen.
//
// in : E_k       - exzentrischen Anomalie (durch kepler(M_0,e)(0<e<1) []
//      e         - Numerische Exzentrizitt (Bahndaten) [rad]
//      [a]       - semi-major axis (z.B. %c_wgs_a) [m]
//
// out: deltaTrel - Korrektur des relativistischen Effekts wegen Bahnexzentrizitt [s]
//
// (matrix-fhig)
// Copyright (c) area7/Christof Schulze  2008
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
deltaTrel=[];

// Display mode
mode(0);
// Display warning for floating point exception
ieee(1);

// laden der astronomischen Konstanten (falls noch nicht geschehen)
if (~isdef('%c_wgs_GM')) then
  exec(%GEOlib_DIR+'/etc/const_astro.sce', -1);
end;

// Bentigte Konstanten
// %c_c = 299792458;               [m/s]
// %c_wgs_GM = 3.986004418e+14;    [m/s]
// %c_wgs_a = 6378137.0;           [m]

// Number of arguments in function call
[%nargout,%nargin] = argn(0);
if (%nargin<2) then
  error('Fehler in Funktion delta_t_rel(..). Zu wenige Argumente');
  return
elseif (%nargin<3) then
  a = %c_wgs_a;   // WGS84 (etc/const_astro.sce) default
end;

// Konstante
F = (-2*sqrt(%c_wgs_GM))/(%c_c^2); // [s/m]

deltaTrel = F * (e ./ sqrt(a)) .* sin(E_k);

endfunction;
