function [axis] = skyplot(azim,elev,maske,line_style,ID)
// SKYPLOT Polar coordinate plot using azimuth and elevation data.
//
// in : azim......... Azimut [deg]
//      elev......... Elevation (90° - Zenitdistanz) [deg]
//      maske........ Elevationsmaske z.B. 10, 15 [deg],
//      line_style... uses the linestyle, specified in the string S (Default: '*').
//                    See PLOT for a description of legal linestyles.
//      ID........... Satelliten-Nr als string!
// out: hsky......... returns a handle to the axes.
//
// BESIPIEL: skyplot(90,50,13,'r*','15');
//
// Copyright (c) area7/Christof Schulze  2008-2010
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
  axis=[];

// Number of arguments in function call
  [%nargout,%nargin] = argn(0)


// ÜberprÜfung der Eingaben
  //if type(azim)~=8 | type(elev)~=8 | type(axim)~=1 | type(elev)~=1 then
  //  error("Input arguments must be numeric.");
  //end;
  if %nargin<2 then
    error("Requires 2 or 3 input arguments.")
  elseif %nargin==3 then
    line_style = 'k-';
  end;
  if size(azim)~=size(elev) then
    error('AZIM and ELEV must be the same size.');
  end;
  if or(elev > 90 | elev < -90) then
    error("ELEV within [-90;90] [deg].")
  end;


// get hold state
  //hold_state = get(gca(),"auto_clear")=="off";
  //set(gca(),"auto_clear","off");
  axis=gca();

// Maske, um alle Satelliten unter dem Horizont auszublenden
  m = find(elev < 0);
  elev(m) = %nan;

// check radial limits and ticks
  zenmax = max(90-elev);
  zenmax = 15 * ceil(zenmax/15);
  elmax = 90;

// Zeichenfläche oberhalb des Horizonts wird weiß. Elevationsmaske grau/braun
// ABER: Neuere Flächen verdecken alles darunterliegende!
// Deshalb wird bei erneutem Aufruf von diesem skyplot die alte Datenmenge
// überzeichnet. Die Eingabe muss vektoriell erfolgen.
  grey = [0.7,0.7,0.7];

  xarc(-90,90,180,180,0,360*64);
  backgr=gce();
  backgr.fill_mode='on';
  backgr.background=27;

  xarc(-90+maske, 90-maske, 180-2*maske, 180-2*maske, 0, 360*64)
  foregr=gce();
  foregr.fill_mode='on';
  foregr.background=-2;
  foregr.line_mode='off';


// make a radial grid with spokes
// -------------------------------------
// make solid circles each 30 deg, and annotate. The horizon (elev=0) is made thicker.
  elev_lines= [0,10,20,30,40,50,60,70,80];
  arcs=[-60    -30 ;... // upper left x
         60     30 ;... // upper left y
        120     60 ;... // width
        120     60 ;... // height
          0      0 ;... // angle 1
        360*64 360*64];
  xset('color',1);
  xset('line style', 1);
  xarcs(arcs,[1,1]);
  arcs=[-80    -70    -50    -40    -20   -10;... // upper left x
         80     70     50     40     20    10;... // upper left y
        160    140    100     80     40    20;... // width
        160    140    100     80     40    20;... // height
          0      0      0      0      0     0;... // angle 1
       360*64 360*64 360*64 360*64 360*64 360*64];
  xset('line style', 3);
  xarcs(arcs, [1,1,1,1,1,1]);
  xset('thickness', 2);
  xset('line style', 1);      // durgezogen
  xarc(-90,90,180,180,0,360*64);
  xset('thickness', 1);

  xset('font', 6, 1.5);
  for i = elev_lines
    xstring(0, i, ' '+string(90-i)+'°');  // Beschriftung der "Höhenlinien" (Zenitwinkel)
  end;
  xset('font',6,1);

// plot spokes
  az = (1:6)*%pi/6;
// define half circle
  caz = cos(az);
  saz = sin(az);
  ca = [-caz;caz];
  sa = [-saz;saz];
  plot(elmax*ca, elmax*sa, 'k-', 'linewidth', 1);
  plot(elmax*ca(:,3), elmax*sa(:,3), 'k-', 'linewidth',2);
  plot(elmax*ca(:,6), elmax*sa(:,6), 'k-', 'linewidth',2);

  if zenmax > elmax then
    plot(zenmax*ca, zenmax*sa, 'k:', 'linewidth', 1);
  end;

// annotate spokes in degree
  rt = 1.1*elmax

  for i = 1:size(az,"*")
    loc1 = string(i*30);
    if i==size(az,"*") then
      loc2 = string(0);
      xstring(rt*saz(i)-2, rt*caz(i)-5, loc1, 0)
      xstring(-rt*saz(i), -rt*caz(i)-5, loc2, 2);
        // nur für die 0, zentieren wäre schön [TODO]
    else
      loc2 = string(180+i*30);
      xstring(rt*saz(i)-2, rt*caz(i)-5, loc1, 0)
      xstring(-rt*saz(i)-10, -rt*caz(i)-5, loc2, 2);
    end;
  
  end;
  xset('font', 6, 2);
  xstring(-rt*saz(6)-12,-rt*caz(6)+10,'NORD', 0);
  xstring(rt*saz(3)+20, rt*caz(3)-10, 'OST', 270);
  xstring(rt*saz(6)-5, rt*caz(6)-20, 'S�D');
  xstring(-rt*saz(3)-10, -rt*caz(3)-15, 'WEST', 270)
  //%teste = gce();
  xset('font', 6, 1);

// brush up axes
  bounds = matrix(max(zenmax,elmax)*[-1,1,-1,1],2, -1);
  isoview(bounds(1,1),bounds(2,1),bounds(1,2),bounds(2,2));
  //set(gca(),"data_bounds", matrix(max(zenmax,elmax)*[-1,1,-1,1],2,-1));

// transform data to Cartesian coordinates (mit Parametern stereographische Projektion)
  // yy = ((2*coth(%pi/4 + (elev/360*%pi)))*180/%pi) .* cos(azim/180*%pi);
  // xx = ((2*coth(%pi/4 + (elev/360*%pi)))*180/%pi) .* sin(azim/180*%pi);

// transform data to Cartesian coordinates.
  yy = (90-elev) .*cos((azim/180)*%pi);
  xx = (90-elev) .*sin((azim/180)*%pi);
  // plot 
  plot(axis, xx, yy, line_style, 'linewidth', 3);

// Endpunkt einzeichnen: Indikator f�r Steigen/Sinken
  plot( xx(size(xx,1),:), yy(size(yy,1),:), 'ko' , 'MarkerSize',10);

// Satellitenbeschriftung
  if %nargin==5 then
    xstring(xx(size(xx,1),:)+1, yy(size(yy,1),:)+1, ID);
    //text(xx(size(xx,1),:)+1,yy(size(yy,1),:)+1,ID, 'fontweight', 'bold');
  end;

  //if %nargout>0 then hsky = axis; end;

  //if ~hold_state then
  //  set(gca(), 'isoview', 'on')
  //  set(gca(), 'axes_visible', 'off')
  //end;

  a.box='off';
  a.axes_visible = 'off';

  //a.isoview='on';
  //set(gca(), 'isoview', 'on')

endfunction;