function [Yf_sats, header, parserror] = sp3_parse_file(yfile)
// Einlesen: SP3-c Dateien (nur Header) (sehr experimentell)
//
// in : yfile: (als Textstring vollständiger Dateipfad, oder)
//      als logische Einheit, wie sie von <i>mopen</i> geliefert wird. 
//          
// out: .....
//
//
// Copyright (c) area7/Christof Schulze  2007-2011
//--------------------------------------------------------------
// private functions:
//  [vdate, err] = sp3_parse_date(datestring)
//  [ldata, perr] = sp3_parseline_P(line)
//  [ldata, perr] = sp3_parseline_EP(line)
//--------------------------------------------------------------
%debug=1;

// Ouput variables initialisation (not found in input variables)
  Yf_sats=[]; // weg
  contained_sat_data=list();
  header=[];
  parserror=[];

  if (exists('%debug', 'local')==1) then
    mprintf('*sp3* parse_file() gestartet.\n')
  end;
// Überprüfungen [TODO]
  
// Datei einlesen
  Yf = mgetl(yfile);  //  This is your input file
  numberoflines = int(size(Yf,1));
  
// read Header
  Yf_header = Yf(1:22);                               // Line -- 1-22
  
  sp3version =  part(Yf_header(1),1:2)                // Line ---   1
  if ('#c' == sp3version) then
    [header, header_err] = sp3c_parse_header(Yf_header);
    parserror = [parserror, header_err];
  else
    // falsche SP3-Version oder keine SP3-Datei
    parserror = [parserror, 'Wrong version of SP3 found, only version SP3c is supported'];
    return;
  end;
  if (exists('%debug', 'local')==1) then timer(); end;
  
  // [TODO] vorübergehend auf P beschränkt
  file_type  = (part(Yf_header(1),3:3));              // Filetype P or V (only P supported)
  if (file_type<>'P') then
    // Falscher Dateityp nur P wird unterstützt
    parserror = [parserror, 'Wrong Filetype of SP3 ''V'', only positiondata ''P'' is supported'];
    return;
  end;
  
  // temporäre Datenstruktur erzeugen
  for i=1:header.svnumber do
    contained_sat_data($+1) = a7_svdata_createsv(header.satnames(i));
    contained_sat_data(i).orbit_almpos_prec = [header.date, ...
                                               header.orbit_type, ...
                                               header.accuracy(i)];
  end;
  
  
  if (exists('%debug', 'local')==1) then
    mprintf('*sp3* parse_file() header durchlaufen.\n')
  end;

  // beginn reading Data
  init_lnnr = 23;                                       // line ---  23
  aktepoche = 1;
  for lnnr=init_lnnr:(size(Yf,1)-1) do
    if ('* '==part(Yf(lnnr),[1:2])) then                // new Epoche header
      [epoche_date, err] = sp3_parse_date(part(Yf(lnnr),4:31));
      if err<>0 then
        parserror = [parserror; sprintf('Parseerror line (%i)', lnnr)];
        return;
      end;
      msatnr=[];
    elseif ('P'==part(Yf(lnnr),1)) then        // -- P
      [tdata, err] = sp3_parseline_P( Yf(lnnr) );
      // Daten in Struktur übernehmen
      parserror = [parserror, err];
      msatnr = find(header.satnames==tdata.name);
      if (msatnr==[]) then
        parserror = [parserror, sprintf('SVname not found in list, line %i.', lnnr)];
      else
        newdataline = [epoche_date, header.orbit_type+tdata.errcode, ...
                       tdata.pos, tdata.pos_sigma, tdata.clk];
               
        contained_sat_data(msatnr).orbit_almpos = ...  
            [contained_sat_data(msatnr).orbit_almpos; newdataline];
      end;
    elseif ('EP'==part(Yf(lnnr),1)) then    // -- EP
      if (msatnr==[]) then
        parserror=[parserror, sprintf('''EP'' data not allowed in first line of epoche, line %i.', lnnr)];
      end;
      [tdata, perr] = sp3_parseline_EP( Yf(lnnr) );
      parserror=[parserror, perr];
      
      
      
    elseif ('V'==part(Yf(lnnr),1)) then    // -- V
      // [TODO] wenn kein V kommt 8 mal 0 anhängen??
    end;
  end;
  
 // [ldata, perr] = sp3_parseline_P( Yf(24) );
 // Yf_sats=ldata;
 
  Yf_sats=contained_sat_data;
  
  if (exists('%debug','local')==1) then
    mprintf('\t * SP3 * file parsed in %f(ckls).\n', timer());
  end;


endfunction;

// ============================================================= private functions
function [vdate, err] = sp3_parse_date(datestring)
// Funktion parst einen Teilstring (Zeile) mit Datumsangabe aus einer SP3-Datei.
//
// in :   datestring - Datumsstring aus einer SP3-Datei
//                     beginnend mit der ersten Zahl des Datums (Spalte 4)
//
// out:   vdate      - Datumsvektor [YYYY,MM,DD,hh,mm,ss.sss]
//        err        - Fehlercode, nicht exact definiert
// -------------------------------------------------------------
  err=0;

  [year,errp] = evstr(part(datestring,1:4)); err=err+errp;
  [month,errp]= evstr(part(datestring,6:7)); err=err+errp;
  [day,errp]  = evstr(part(datestring,9:10)); err=err+errp;
  [hour,errp] = evstr(part(datestring,12:13)); err=err+errp;
  [minu,errp] = evstr(part(datestring,15:16)); err=err+errp;
  [secs,errp] = evstr(part(datestring,18:28)); err=err+errp;
  vdate = [year,month,day,hour,minu,secs];
  
endfunction;


// ============================================================= private functions
function [bdata, symbol1, symbol2, perr] = parse_sp3_databl(dblockline)
// Funktion parst eine Zeile eines Datenblocks
//
// in :   Yf - Vektor mit Strings der eingelesenen Datei
//
// out:   state     - 
// -------------------------------------------------------------
  perr=0;
  
  symbol1=part(dblockline,1);                       // Datentyp: P-Position, V-Bewegung
  symbol2=part(dblockline,2);                       // Satelite Type G-GPS R-Glonass M-Mixed
  
  if symbol1=='P' then
    [satid,perr]   =evstr(part(dblockline,3:4));
    [xx,perr]      =evstr(part(dblockline,5:18))*1000;
    [yy,perr]      =evstr(part(dblockline,19:32))*1000;
    [zz,perr]      =evstr(part(dblockline,33:46))*1000;
    [clk,perr]     =evstr(part(dblockline,47:60));
    if (clk<>999999.999999) then
     [sigma_x,perr]=evstr(part(dblockline,62:63));
     if sigma_x==[] then sigma_x=0; else sigma_x = base_values^sigma_x; end;
     [sigma_y,perr]=evstr(part(dblockline,65:66));
     if sigma_y==[] then sigma_y=0; else sigma_y = base_values^sigma_y; end;
     [sigma_z,perr]=evstr(part(dblockline,68:69));
     if sigma_z==[] then sigma_z=0; else sigma_z = base_values^sigma_z; end;
     [sigma_c,perr]=evstr(part(dblockline,71:73));
     if sigma_c==[] then sigma_c=0; else sigma_c = base_clkrate^sigma_c; end;
    else
     sigma_x=0;
     sigma_y=0;
     sigma_z=0;
     sigma_c=0;
    end;
    bdata=[satid,xx,yy,zz,clk,sigma_x,sigma_y,sigma_z,sigma_c]
  else // TODO
    perr=4;
    mprintf("V*,EP,EV Datensätze werden nicht unterstützt\n");
  end;
  
  bdata = bdata;   //[1,2,3]

endfunction;

// ============================================================= private functions
function [ldata, perr] = sp3_parseline_P(line)
// Funktion parst eine Zeile eines Datenblocks. beginnenend mit Pxxx
// (The Position and Clock Record) Spezification Z.423
//
// in :   line - line of sp3-file with Positiondata
//
// out:   ldata.name [string]
//                 .pos( [x,y,z] )                 [m]
//                 .pos.sigma( [dx,dy,dz] ) [mm]
//                 .clk( [clk, sigma_c] )
//                 .flags( [flag1, flag2, flag3, flag4] )
//                 .errcode( [int] )     - value out of specified range
// -------------------------------------------------------------
  ldata=[]; perr=[];
  errcode=0; // wird später an orbit_type angebracht
  
  satid   = (part(line,2:4));
  [xx,perr]      = evstr(part(line, 5:18))   // F14.6 [km]
  if xx==[] then xx=0; errcode=10;  end;
  [yy,perr]      = evstr(part(line,19:32))   // F14.6 [km]
  if yy==[] then yy=0; errcode=10; end;
  [zz,perr]      = evstr(part(line,33:46))   // F14.6 [km]
  if zz==[] then zz=0; errcode=10;  end;
  pos = [xx,yy,zz]*1000;                     // [x,y,z] [m]
  // Fehlerhafte oder fehlende Positionen sind mit 0.000000 gekennzeichnet
   
  [clk, perr]     = evstr(part(line,47:60));      // F14.6 [microsec]
  // Fehlerhafte oder fehlende Uhrdaten sind mit 999999[.999999] gekennzeichnet
  if (clk==[]) then clk=999999.999999; errcode=10; end;
    
  [sigma_x, perr] = evstr(part(line, 62:63));
  if sigma_x==[] then sigma_x=0; errcode=10; else
    sigma_x = header.base_values^sigma_x; end;
    
  [sigma_y, perr] = evstr(part(line, 65:66));
  if sigma_y==[] then sigma_y=0; errcode=10; else
    sigma_y = header.base_values^sigma_y; end;
    
  [sigma_z, perr] = evstr(part(line, 68:69));
  if sigma_z==[] then sigma_z=0; errcode=10; else
     sigma_z = header.base_values^sigma_z; end;
    
  [sigma_c, perr] = evstr(part(line, 71:73));
  if sigma_c==[] then sigma_c=0; errcode=10; else 
     sigma_c = header.base_clkrate^sigma_c; end;
  
  flag1 = part(line, 75);           // Clock Event Flag   E
  if (flag1<>'E') |(flag1==' ') then flag1=['']; end; 
  flag2 = part(line, 76);           // Clock Pred. Flag   P
  if (flag2<>'P') | (flag2==' ') then flag2=['']; end;
  flag3 = part(line, 79);           // Maneuver Flag      M
  if (flag3<>'M') | (flag3==' ') then flag3=['']; end;
  flag4 = part(line, 80);           // Orbit Pred. Flag   P
  if (flag4<>'P') | (flag4==' ') then flag4=['']; end;
   
  ldata = struct('name',satid, ...
                 'pos', pos, ...
                 'pos_sigma', [sigma_x, sigma_y, sigma_z], ...
                 'clk', [clk,sigma_c], ...
                 'flags', [flag1, flag2, flag3, flag4], ...
                 'errcode', errcode);
                 
  if perr==0 then perr=[]; end;
                 
endfunction;

// ============================================================= private functions
function [ldata, perr] = sp3_parseline_EP(line)
// Funktion parst eine Zeile eines Datenblocks beginnend mit EPxx
// (optional Position and Clock Correlation Record) Spezification Z.449
//
// in :   line - line of sp3-file with Positiondata
//
// out:   ldata     - 
// -------------------------------------------------------------
  ldata=[], perr=[];

  satid   = (part(line,2:4));
  [x_sdev ,perr] = evstr(part(line, 5:8))   // I4 [mm]
  if x_sdev==[] then x_sdev=0; errcode=10;  end;
  [y_sdev,perr]  = evstr(part(line,10:13))  // I4 [mm]
  if y_sdev==[] then y_sdev=0; errcode=10; end;
  [z_sdev,perr]  = evstr(part(line,15:18))  // I4 [mm]
  if z_sdev==[] then z_sdev=0; errcode=10;  end;
  pos = [xx,yy,zz]*1000;                     // [x,y,z] [m]
  
  [clk_sdev,perr] = evstr(part(line,20:26));  // I7 [picosec]
  [xy_corr,perr] = evstr(part(line,28:35));   // I8
  [xz_corr,perr] = evstr(part(line,37:44));   // I8
  [xc_corr,perr] = evstr(part(line,46:53));   // I8  
  [yz_corr,perr] = evstr(part(line,55:62));   // I8
  [yc_corr,perr] = evstr(part(line,64:71));   // I8
  [zc_corr,perr] = evstr(part(line,73:80));   // I8

  if perr==0 then perr=[]; end;

  //[TODO] generate return structure

endfunction;


// ============================================================= private functions
function [ldata, perr] = sp3_parseline_V(line)
// Funktion parst eine Zeile eines Datenblocks, beginnend mit Vxxx
// (Optional Velocity and Clock Rate-of- Change Record.) Spezification ...
//
// in :   line - line of sp3-file with Positiondata
//
// out:   ldata     - 
// -------------------------------------------------------------
ldata=[], perr=[];

// When the position/velocity flag is set to 'V' in line one, then each
// P-line for every sv will be followed by a corresponding V-line
// (sametimes ther may be a Position and Clock Correlation Record in between the two).
// The satellite velocity components are given in columns 5-46 in units
// of decimeters/second and have a precision of 10**-4 millimeters/second. 
// Columns 47-60 give the rate-of-change of the clock correction in units of
// 10**-4 microseconds/second.  The precision of this parameter is 10**-16
// seconds/second.  Bad or absent velocity values are to be set to 0.000000.  
// Bad or absent clock rate-of-change values are to be set to _999999.999999.  
// The six integer nines are required, whereas the fractional part nines are 
// optional.  In a manner similar to the Position and Clock Record,
// columns 62-69 hold two-digit exponents for representing the standard
// deviation of the X-, Y-, Z-velocities (e.g., 1.25**14 = 22.7374 or
// approximately 0.0022 mm/sec).  Columns 71-73 hold a three-digit exponent for
// representing the standard deviation of the clock correction rate-of-change
// (e.g., 1.025**191 = 111.7528 or approximately 0.0112 psec/sec).  A value of
// 99 or 999 would mean that a standard deviation was too large to represent.
// If a standard deviation is unknown, its field is left blank.  If one or more
// fields in columns 61 through 73 are omitted, a Velocity and Clock Rate-of-
// Change Record may contain less than 73 columns.

  if perr==0 then perr=[]; end;
endfunction;