function [a, f, b] = ell_param(ell)
// Gibt Ellipsoidparameter zurück
//
// Wie: [a, f, b] = ell_param(ell)
// in : - ell ist Textstring: 'wgs84' (default), 'grs80', oder 'bessel'
//
// out: a - Äquatorachsradius (semi-major axis) [m]
//      b - Polachsradius (semi-minor axis) [m]
//      f - Abplattung (flatteinig) []
//
// (nicht matrixfähig)
// 
// Copyright (c) area7/Christof Schulze  2008-2010
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
  a=[]; b=[]; f=[];

// Number of arguments in function call
  [%nargout,%nargin] = argn(0);
  if (%nargin<1) then
    ell = 'wgs84';   // WGS84 default
  end;

  ell = convstr(stripblanks(ell),'l');
  
  if (ell=='list') then               // enthaltene ellipsoide aufzählen
    a = ['bessel', 'wgs84', 'grs80'];
    return;
  elseif (ell=='bessel') then         // Bessel-Ellipsoid
    a = 6377397.155;
    f = 1/299.1528128;
    b = (1-f)*a;
  elseif (ell=='wgs84') then          // WGS84-Ellipsoid
    a = 6378137.0;
    f = 1/298.257223563;
    b = (1-f)*a;
  elseif (ell=='grs80') then          // GRS80-Ellipsoid
    a = 6378137.0;
    f = 1/298.257222101;
    b = (1-f)*a;
  
  else
    error('Fehler in Funktion ell_param(..). Nicht-definiertes Ellipsoid');
    return;
  end;

  c = (a^2) / b;
  es = (a^2 - b^2) /(b^2);
  n  = (a - b) / (a + b); // [TODO]    variable Anzahl Ausgabeparameter

endfunction;