function [xs,ys,zs,delta_Ts,delta_rho_rel] = eph2xyz(tc,Prs,a0,a1,a2,a,te,e,i_0,Omega_0,omega_klein,M_0,Omega_dot,i_dot,delta_n,C_us,C_uc,C_is,C_ic,C_rs,C_rc)
// Funktion zur Berechnung der Satellitenkoordinaten in xyz aus den
// Ephemeriedendaten des Satelliten.
//
// (vielleicht nicht matrix-fhig)
// Copyright (c) area7/Christof Schulze  2007-2010
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
  xs=[]; ys=[]; zs=[];
  delta_Ts=[];
  delta_rho_rel=[];

// laden bentigter Funktionen (falls noch nicht geschehen)
  if (~isdef(kepler)) then
    getf(%GEOlib_DIR+'macros/phys/kepler.sci');
  end;
  if (~isdef(delta_t_rel)) then
    getf(%GEOlib_DIR+'macros/gps/delta_t_rel.sci');
  end;
  if (~isdef(%c_c)) then
    exec(%GEOlib_DIR+'etc/const_astro.sce');
  end;

// Konstanten im WGS84
// %c_wgs_GM = 3.986004418e+14;     // [m/s]
// %c_c   = 299792458;              // [m/s]
  Omega_e = 7.2921151467*(10^(-5)); // [rad/s]

// mittlere Bewegung der Keplerbahn
  n0 = sqrt(%c_wgs_GM./(a.^3));

// mittlere Bewegung der gestrten Bahn
  n = n0 + delta_n;

// Berechnung des Signalsendezeitpunktes in der GPS Zeitskala
  Ts = tc - (Prs./%c_c);
  dt = Ts - te;

// mittlere Anomalie
  M = M_0 + (n.*dt);

// exzentrische Anomalie
  E = kepler(M,e);            // noch nicht matrix-fhig

// Korrektur des relativistischen Effektes
  //delta_Trel = (-(2.*e).*sqrt(%c_wgs_GM.*a))/(%c_c^2) .*sin(E);
  // delta_Trel = -4.442807309*10^(-10)*e*sqrt(a) .*sin(E);
  delta_Trel = delta_t_rel(e, E, a);
  
  delta_Ts = a0 + (a1.*dt) + (a2.*(dt.^2));
  dTs = delta_Ts + delta_Trel;

  delta_rho_rel = delta_Trel * %c_c;
  dts = dt - dTs;

// Berechnung von Bahnparametern und Koordinaten zum Signalsendezeitpunkt

  // nochmal mittlere Anomalie
    M = M_0 + (n.*dts);

  // nochmal exzentrische Anomalie
    E = kepler(M,e,E);

  // wahre Anomalie
    v = atan(sqrt(1 - e^2).*sin(E), (cos(E) - e));

  if (v<0) then
    v = v + 2*%pi;
  end;

  // Argument der Breite:
  us = omega_klein + v;

  // Verbesserung fr Argument der Breite usw.
    delta_u = (C_us.*sin(2*us)) + (C_uc.*cos(2*us));
    delta_r = (C_rs.*sin(2*us)) + (C_rc.*cos(2*us));
    delta_i = (C_is.*sin(2*us)) + (C_ic.*cos(2*us));

  // korrigiertes Argument der Breite
    u = us + delta_u;

  // korrigierter Orbitradius
    r = a.*(1 - (e.*cos(E))) + delta_r;

  // korrigierte Inklination
    i = i_0 + delta_i + (i_dot.*dts);

  omega = Omega_0 + ((Omega_dot - Omega_e).*dts) - (Omega_e.*te);

  x0 = r.*cos(u);
  y0 = r.*sin(u);
  z0 = 0;
  xs = (x0.*cos(omega)) - (y0.*cos(i)).*sin(omega);
  ys = (x0.*sin(omega)) + (y0.*cos(i)).*cos(omega);
  zs = y0.*sin(i);

endfunction;