function [B, L] = gk2bl(R, H, ell)
// Transformation: Gau-Krger-Koordinaten (deutsche Konvention)
// in  Geodtische ellipsoidische Koordinaten
//
// [B, L] = gk2bl(R, H [,ell])
//
// in :  R   - Rechtswert [m],
//       H   - Hochwert [m]
//       ell - Textstring: 'wgs84', 'grs80', oder 'bessel' (default)
// out:  B   - Breite [grad.decimale],
//       L   - Lnge [grad.decimale]
//
// Geschlossene Formeln, Reihenentwicklung nur fr Fupunktbreite aus
// Meridianbogenlnge nach K. Schndelbach, Skript Landesvermessung
//
// (matrixfhig)
//
// Copyright (c) area7/Christof Schulze  2008
//--------------------------------------------------------------

if nargin < 3, ell = 'bessel'; end;	// Bessel default

// laden der Ellipsoidparameter
  [a, f, b] = ell_param(ell);

// GK Konvention fr die Bundesrepublik Deutschland
   masstab = 1;
   y0 = 500000;

// Meridianbogenlnge
   x = H;
   g = x / masstab;

// Berechnung der Fupunktbreite aus Meridianbogenlnge
   kz = floor(R * 1e-6);
   L0 = kz * 3;
   y  = R - (kz + 0.5)*1e6;

   bs  = (1+n) / a / (1 +n^2 / 4 + n^4 / 64) * g;
   bf3 = bs  + 1.5*n * (1 - n^2*9/16) * sin(2*bs);
   bf2 = bf3 + n^2/16 * ( 21 - 27.5* n^2) * sin (4*bs);
   bf1 = bf2 + 151/96 * n^3 * sin(6*bs);
   bf  = bf1 + 1097/512 * n^4 * sin(8*bs);
   
// Berechnung von Breite und Lnge
   eta2 = es * cos(bf).^2;
   v2 = 1 + eta2;
   v = sqrt(v2);
   ys = y / masstab / c;

   ll = v ./ cos(bf) .* sinh(ys) .* (1 - eta2.^2 ./ 6 .* ys.^2 - 0.1*es*ys.^4);
   lroh = atan(ll);

   bb = tan(bf) .* cos(v .* lroh) .* (1 - eta2 .* lroh.^4 / 6);
   broh = atan (bb);

   b = broh * 180/%pi;
   l = lroh * 180/%pi + L0;
   
endfunction;
