function [E]= kepler(M,e,E0)
// Berechnung der exzentrischen Anomalie (Keplerelement)
//
// [E] = kepler(M, e [, E0])
//
// in : M  - mittlere Anomalie (Keplergleichung),
//      e  - Exzentizitt (0<e<1)
//      E0 - Startwert der ex. Anomalie, optional (default M)
//
// out: E  - exzentrische Anomalie
//
// Abbruchkriterium der Iteration:   1e-10
//
// (matrixfhig)
//
// Copyright (c) area7/Christof Schulze  2007
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
  E=[];

// Number of arguments in function call
  [%nargout,%nargin] = argn(0);
  if (%nargin<2) then
    error('Fehler in Funktion kepler(..). Zu wenige Argumente');
    return;
  elseif (%nargin<3) then
    E0 = M;   // WGS84 default
  end;

  E1 = E0;
  E2 = M + e .* sin(E1);
  while (abs(E1 - E2) > 10^(-10))
    E1 = E2;
    E2 = M + e .* sin(E1);
  end;
  E = E2;
  
endfunction;
