function [epsilon_0, delta_epsilon, delta_psi] = par_nutation(t_j2k)
// Berechnet die mittlere Ekliptikschiefe epsilon_0,
// die Nutation in der Länge delta_psi und in Schiefe delta_epsilon.
//
// in : t_j2k         - Zeit in Epoche J2000
//      [in Julianischen Jahrhunderten (von 36525 Tagen)]
//
// out: epsion_0      - mittlere Ekliptikschiefe [rad] (Mean obliquity)
//      delta_epsilon - Nutation in Schiefe      [rad]
//      delta_psi     - Nutation in Länge	        [rad]
//
// Genauigkeit von delta_epsilon und delta_psi liegt bei ca. einer Bogensekunde.
// epsilon_0 ist wesentlich genauer
// (matrixfähig)
// Copyright (c) area7/Christof Schulze  2007-2010
//--------------------------------------------------------------

// Zeitdifferenz von J2000
d  =  t_j2k .* 36525;

// Parameter der Nutation aus CL_mod_nutationArg()
  KOEF=[134.96340251d0, 1717915923.2178d0, 31.8792d0, 0.051635d0, -0.00024470d0;
       357.52910918d0,  129596581.0481d0, -0.5532d0,-0.000136d0, -0.00001149d0;
        93.27209062d0, 1739527262.8478d0,-12.7512d0,-0.001037d0,  0.00000417d0;
       297.85019547d0, 1602961601.2090d0, -6.3706d0, 0.006593d0, -0.00003169d0;
       125.04455501d0,   -6962890.2665d0,  7.4722d0,  0.007702d0,-0.00005939d0;]; //Omega
       
       //Omega = Mean longitude of Moon's ascending node
       
  //changement unitees
  KOEF = [(%pi/180)*KOEF(:,1), (%pi/180)*(1/3600)*KOEF(:,2:5)]; // [rad]

// Hilfsfunktionen
f1 = (125 - 0.05295 .* d) .* (%pi/180.0);
f2 = (200.9 + 1.97129 .* d) .* (%pi/180.0);

epsilon_0 = (84381.448 - 46.815.*t_j2k - 0.00059d0.*t.^2 + 0.001813d0.*t.^3) * (%pi/180)/3600;

delta_psi = (-0.0048 .* sin(f1) - 0.0004 .* sin(f2)) * (%pi/180);
delta_epsilon = ( 0.0026 .* cos(f1) + 0.0002 .* cos(f2))* (%pi/180);

endfunction;