function [aa, zz, ss] = xyz2asz(xr, yr, zr, xs, ys, zs)
// Umwandlung: Kartesische (WGS84) in topozentrische Koordinaten
//
// in : - X,Y,Z in Meter
// 
// out: - A, Z, in Degree.Decimale,
//      - S in Meter
//
// Formeln aus Heck (1988):
//
// (matrixfähig)
// 
// Copyright (c) area7/Christof Schulze  2008-2010
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
  aa=[]; zz=[]; ss=[];


// Number of arguments in function call
[%nargout,%nargin] = argn(0);
if (%nargin<6) then
  error('Fehler in Funktion xyz2asz(..). Zu wenige Argumente');
  return
end;

if (~compareVectors(list(xr, yr, zr, xs, ys, zs))) then
  error('Fehler in Funktion xyz2asz(..). Die Argumente haben nicht dieselbe Dimension');
end;

[bb, ll, hh] = xyz2blh(xr, yr, zr);

phi = bb * %pi/180;
lambda = ll * %pi/180;

dx = xs - xr;
dy = ys - yr;
dz = zs - zr;

ss = sqrt( dx.^2 + dy.^2 + dz.^2);

zz = acos((cos(phi) .* cos(lambda) .* dx + cos(phi) .* sin(lambda) .* dy + sin(phi) .* dz) ./ ss );

aa = atan( (-sin(lambda) ./ dx + cos(lambda) .* dy) , (-sin(phi) .* cos(lambda) .* dx - sin(phi) .* sin(lambda) .* dy + cos(phi) .* dz));

zz = zz *(180/%pi);
aa = aa *(180/%pi);

endfunction;