function [bb,ll,h] = xyz2blh(x,y,z,ell)
// Umwandlung: Kartesische in Ellipsoidische Koordinaten
//
// Wie: [bb,ll,h]=xyz2blh(x,y,z[,ell])
// in : - X,Y,Z in Meter
//      - ell ist Textstring: 'wgs84' (default), 'grs80', oder 'bessel'
// out: bb - latitude [Decimaldegree]
//      ll - longitude [Decimaldegree]
//       h - height over ellipsoid [Meter]
//
// Formeln aus Hofmann-Wellenhof u.a(1994):"GPS in der Praxis"
// Keine negativen H�hen!
//
// (matrixfähig)
// 
// Copyright (c) area7/Christof Schulze  2007-2010
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
bb=[]; l=[]; h=[];

// Number of arguments in function call
[%nargout,%nargin] = argn(0);
if (%nargin<3) then
  error('Fehler in Funktion XYZ2BLH(..). Zu wenige Argumente');
  return
elseif (%nargin<4) then
  ell = "wgs84";   // WGS84 default
end;

// laden der Ellipsoidparameter
[a,f,b]=ell_param(ell);

e1q = (a^2 - b^2)/(a^2);
e2q = (a^2 - b^2)/(b^2);

p = sqrt(x.^2 + y.^2);              // Hilfsgröße
theta = atan((z.*a) , (p.*b));      // Hilfsgröße

bb = atan((z+e2q.*b.*(sin(theta)).^3), (p-e1q.*a.*(cos(theta)).^3)); // [rad]
ll = atan(y, x);                    // [rad]

n = a ./sqrt(1-e1q .*(sin(bb)).^2); // Normalkrümmungsradius
//n = a^2 ./ sqrt(a^2 .* (cos(bb)).^2  + b^2 .* (sin(bb)).^2);

h = p ./cos(bb) - n;                // [meter]

rho = 180/%pi;
bb = bb*rho;
ll = ll*rho;
endfunction;
