function n_0 = aequiKor(t_j2k)
// "Gleichung der Äquinoktien"
//
// in : t_j2k - Zeit von der Epoche J2000.0 mit angeähngten Dezimalen in UT1
//            [Julianischen Jahrhunderten (von 36525 Tagen)]
// out: n_0 - Der auf der Ekliptik gemessenen Winkelunterschied zwischen
//            wahrem und mittlerem Frühlingspunkt [rad]
//
// (matrixfähig, experimentell)
//
// Copyright (c) area7/Christof Schulze  2007-2010
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
  delta_m=[]; delta=zeros(size(t_j2k));
  
// Parameter der Nutation aus CL_mod_nutationArg()
  KOEF=[134.96340251d0, 1717915923.2178d0, 31.8792d0, 0.051635d0, -0.00024470d0;
       357.52910918d0,  129596581.0481d0, -0.5532d0,-0.000136d0, -0.00001149d0;
        93.27209062d0, 1739527262.8478d0,-12.7512d0,-0.001037d0,  0.00000417d0;
       297.85019547d0, 1602961601.2090d0, -6.3706d0, 0.006593d0, -0.00003169d0;
       125.04455501d0,   -6962890.2665d0,  7.4722d0,  0.007702d0,-0.00005939d0;]; 
  //changement unitees
  KOEF = [(%pi/180)*KOEF(:,1), (%pi/180)*(1/3600)*KOEF(:,2:5)]; // [rad]
  
// Korrektur eingeführt seit 1. Januar 1997 (JD 2450449.5) (j2k -1095.5)
// Einfluß des Aufsteigenden Mondknotens (Näherung)
// (Mean longitude of Moon's ascending node) [F(5) ...] = CL_mod_nutationArg(t_j2k)
  Omega = KOEF(5,1) + KOEF(5,2)*t_j2k + KOEF(5,3).*t_j2k.^2 + KOEF(5,4)*(t_j2k^3) +KOEF(5,5).*(t_j2k^4); // [rad]

  sec2rad=(1/3600)*(%pi/180);
  A = sec2rad*0.00264;
  B = sec2rad*0.000063;
  
  k = find(t_j2k < -1095.5);
  delta(k) = A .* sin(Omega(k)) + B .* sin(2.*Omega(k));

// Korrektur durch die Nutation in der Länge delta_psi und der wahren Schiefe der Ekliptik epsilon_0
  [epsilon_0, delta_epsilon, delta_psi] = par_nutation(t_j2k);

// "Gleichung des Äquinoktiums"
  n_0 = delta_psi .* cos(epsilon_0) + delta;

endfunction;