function jd = dat_cal2jd(varargin)
// Umrechnung eines Kalenderdatums in ein Julianisches Datum.
// Berechnung mit Daten im Gregorianischen Kalender. 
// Achtung bei Daten vor dem 5. Okt. 1582 wird davon ausgegangen daß sich
// das angegebene Datum im Julianischen Kalender befindet.
//
// jd = cal2jd(cal)
// jd = cal2jd(y, m, d [, h, m, s])

// in : cal - Datumsvektor [Jahr; Monat; Tag [; Stunde; Minute; Sekunde]]
//      y   - Jahr (ungekuerzt!)
//      m   - Monat
//      d   - Tag
//      h,m,s - Weltzeit Greenwich [dezimale Stunden]
//
// out: jd  - Julianisches Datum (JD)
//
// Die Umwandlung ist exakt. (matrixfähig)
//
// Copyright (c) area7/Christof Schulze  2007-2010
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
  jd=[]; hour=0; minute=0; second=0;
  
// Number of arguments in function call
  [%nargout,%nargin] = argn(0);
  if ~(%nargin == 1 | %nargin==0| (%nargin >= 3 & %nargin <= 6))
    error('Scilib-GEO: Wrong number of input arguments');
  end;  

  if (%nargin<=1) then
    if (%nargin==0) then
      time = datevec(now())';
    else //(%nargin==1)
      time=varargin(1);
      if ((size(time,1)<3) | (size(time,1)>6)) then
        error('Scilib-GEO: Wrong size of input arguments');  
      end;
    end;
  elseif (%nargin>=3 & %nargin<=6) then
    time=[];
    for i=1:size(varargin)
      time=[time;varargin(i)];   // Fehler kommt automatisch
    end;
  end;
  
  sz=size(time,1);
  year = time(1,:);
  month = time(2,:);
  day = time(3,:);
  if (sz >= 4); hour = time(4,:); end
  if (sz >= 5); minute = time(5,:); end
  if (sz >= 6); second = time(6,:); end
    
// Überprüfung von year, month und day auf ganzzahligkeit
  condition = find(month < 1 | month > 12 | year < -4712 | month<>int(month) | year<>int(year) | day<>int(day));
  if ~isempty(condition)
    error("Scilib-GEO: Invalid arguments, year,month or day out of valid ranges.");
  end
  
  k = find(month <= 2); 
  year(k) = year(k) - 1; 
  month(k) = month(k)+12; 
  hours = hour + minute/60 + second/3600;
  
  A = int(year./100.0);
  B = 2 - A + int(A / 4);
  
  jd = int(365.25.*(year + 4716)) + int(30.6001.*(month+1)) + day - 1524.5;
    
  k = find(jd + hours >= 2299160.5); // 2299160.5 = 5. Okt. 0h 1582 Julian Calendar
  jd(k) = jd(k) + B(k); // Gregorian Calendar
  
  jd = jd + hours./24.0;
endfunction;