function varargout = dat_jd2cal(jd)
// Umrechnung von Julianischem Datum in Kalenderdatum
//
// cal = dat_jd2cal(jd)
// [year, month, day, hour, minute, second]=dat_jd2cal(jd)
//
// in : jd  - Julianisches Datum [days,decimal] (1xn)
//
// out: year  - Jahr
//      month - Monat
//      day   - Tag
//      hour, minute, second
//
// Die Umwandlung ist exakt. (matrixfähig)
//
// Copyright (c) area7/Christof Schulze  2007-2010
//--------------------------------------------------------------
  
// Number of arguments in function call
  [%nargout,%nargin] = argn(0);
  if ((%nargout<>1) & (%nargout<>4) & (%nargout<>6)) then
    error('Scilib-GEO: Wrong number of output arguments.');
  end;
  if (%nargin <> 1) then
    error('Scilib-GEO: Wrong number of input arguments.');
  end;

  if ~isempty( find(jd<0)) then
    error('Scilib-GEO: Julian Date cannot be negative.');
  end;
  
  if (size(jd,1)<>1) then
    error('Scilib-GEO: Julian Date matrix has wrong size.');  
  end;
  
  I = int(jd + 0.5);
  F = jd + 0.5 - I;
  
  A = I;
  X = int((I - 1867216.25) ./ 36524.25);
  k = find(I >= 2299161);

  A(k) = I(k) + 1 + X(k) - int(X(k) ./ 4.0);

  B = A + 1524;
  C = int((B-122.1)./365.25);
  D = int(365.25.*C);
  E = int((B-D)./30.6001);

  dd = B - D - int(30.6001.*E) + F; // decimal day
  
  month = E - 1;
  year = C - 4716;
  k = find(E == 14 | E == 15);
  month(k) = E(k) - 13;
  year(k) = C(k) - 4715;

  day = floor(dd);
  dh = (dd-day).*24;  // decimal hour
  hour = floor(dh);
  minute = floor((dh-hour)*60);
  second = ((dh-hour)*60 - minute)*60;
  
// output

  if (%nargout == 1) then
    varargout(1) = [year;month;day;hour;minute;second];
  elseif (%nargout == 4) then
    varargout(1) = year;
    varargout(2) = month;
    varargout(3) = day;
    varargout(4) = dh;
  else
    varargout(1) = year;
    varargout(2) = month;
    varargout(3) = day;
    varargout(4) = hour;
    varargout(5) = minute;
    varargout(6) = second;
  end;
  
endfunction;