function [lsecs] = dat_leapseconds(year, month, day, utc)
// Matrix mit allen eingeführten Schaltsekunden (Bulletin C 41 Feb. 2011)
// anzubringen jeweils nach 23:59:59 UTC (als 23:59:60 UTC)
//
// in : year  - Jahr (ungekuerzt!)
//      month - Monat
//      day   - Tag
//      utc   - Weltzeit Greenwich [dezimale Stunden]
// 
// in : DT    - Dezimaltage (scilab datenum)
//      utc    - Weltzeit Greenwich [dezimale Stunden]
//
// out: lsecs - Die Daten sämtlicher Schaltsekunden, als Array
//            - Anzahl der Schaltsekunden bis zum eingegebenen Datum
//
// (nicht matrixfähig)
//
// Copyright (c) area7/Christof Schulze  2009-2011
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
  lsecs=[]

//       YYYY, MM, DD, sci:DT, +-leapsec
  secs=[ 1972,  6, 30, 720440, +1 ;
         1972, 12, 31, 720624, +1;
         1973, 12, 31, 720989, +1;
         1974, 12, 31, 721354, +1;
         1975, 12, 31, 721719, +1;
         1976, 12, 31, 722085, +1;
         1977, 12, 31, 722450, +1;
         1978, 12, 31, 722815, +1;
         1979, 12, 31, 723180, +1;
         1981,  6, 30, 723727, +1;
         1982,  6, 30, 724092, +1;
         1983,  6, 30, 724457, +1;
         1985,  6, 30, 725188, +1;
         1987, 12, 31, 726102, +1;
         1989, 12, 31, 726833, +1;
         1990, 12, 31, 727198, +1;
         1992,  6, 30, 727745, +1;
         1993,  6, 30, 728110, +1;
         1994,  6, 30, 728475, +1;
         1995, 12, 31, 729024, +1;
         1997,  6, 30, 729571, +1;
         1998, 12, 31, 730120, +1;
         2005, 12, 31, 732677, +1;
         2008, 12, 31, 733773, +1];
	 
// Number of arguments in function call
  [%nargout,%nargin] = argn(0);

  select %nargin
    case 0    // keine Parameter alles ausgeben
      lsecs = secs;
      break;
      
    case 1    // 1 Parameter 'd' 'dt' alles entweder mit Datum oder DT ausgeben
      if type(year)<>10 then
		error('Type of parameter is incorrect.');
      end
	  if year=='dt' | year=='DT' then
	    lsecs = secs(:,[4,5]);
      elseif year=='d' | year=='D' then
	    lsecs = secs(:,[1,2,3,5]);
	  elseif type(year)== then
      else
	    error('The argument must be of the type *d* or *dt*');
	  end;
      break;
      
    case 2    // Zeit in DT und UTC [sec]
      if (type(year)<> 1) | (type(month)<>1) then
		error('Type of parameters incorrect.');
	  end
      if (size(year) <> size(month)) then
		error('The two arguments must have the same size.');
	  end;
    
      DT = year;
      a = find(secs(:,4)<DT); // Die Uhrzeit (=) spielt keine Rolle da eigentlich immer vor 23:59:59-60 [TODO]
      
      lsecs= sum(secs(a,[5]));
      break;
      
    else
	  error('Number of parameters incorrect.');
    end;

endfunction;