function [gast, gmst] = dat_ut12gast(t_j2k, ut1)
// Berechnet die wahre Sternzeit Greenwich (GAST) aus UT1 und J2000.0
// Calculates the Greenwich Apparent Sideral Time (GAST) from UT1 and J2000.0
//
// in :  t_j2k  - Zeit in der Epoche J2000.0
//             [Julianischen Jahrhunderten (von 36525 Tagen)]
//      ut1  - Weltzeit Greenwich [dezimale Stunden]
//
// out: gast - Wahre Sternzeit Greenwich [dezimale Stunden]
//             
//      gmst - Mittlere Sternzeit Greenwich [dezimale Stunden]
//             (Global Mean Sidereal Time)
//
// Die Genauigkeit liegt wegen der Genauigkeit der Funktion für die Nutation
// nur bei ~ 0,1 [sec].
//
// (matrixfähig) (experimentell !!!)
//
// Copyright (c) area7/Christof Schulze  2007-2010
//--------------------------------------------------------------
// used functions: par_nutation
//--------------------------------------------------------------
// Ouput variables initialisation (not found in input variables)
  gast=[]; gmst=[];

  gmst = ut1 + (24110.54841 + 8640184.812866 * t_j2k + 0.093104 * t_j2k.^2 - 6.2e-6 * t_j2k.^3) / 3600;


  [epsilon_0, delta_epsilon, delta_psi] = par_nutation(t_j2k); //Achtung [rad]
  epsi = (epsilon_0 + delta_epsilon);
  
  sec2rad=(1/3600)*(%pi/180);
  eq   = (delta_psi .* cos(epsi))/sec2rad;    // ersetzen durch aequiKor() wegen delta

  gast = gmst + eq/15;              // ersetzen durch aequiKor()

  gast = (gast - fix(gast /24)*24 + 24) - fix((gast - fix(gast / 24)*24 + 24)/24)*24;
  gmst = (gmst - fix(gmst /24)*24 + 24) - fix((gmst - fix(gmst / 24)*24 + 24)/24)*24;

endfunction;