function [d, dv] = deg2dms(phi, flag)
// Converts phi from decimal degrees into degree.minutes-seconds,
// output always as columnvector
//
// in : phi  - angle/direction in decimal degrees
//     flag  - 's' if formated output is prefered, default=""
//          
// out:   d  - angle/direction [dd.mmss] (and following decimal seconds) 
//             or angle/direction as formated string [dd°mm'ss.ss'']
//        dv - angle/direction as vector [dd, mm, ss.ss]
//
// matrixfähig
// Copyright (c) area7/Christof Schulze  2010-2011
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
  d=[]; dv=[];

// Number of arguments in function call
  [%nargout,%nargin] = argn(0);
  if (%nargin<1) | (%nargin>2) then
    err=58;
    error('Wrong number of input arguments:', err);
  elseif (%nargin==1) then
    flag = '';
  end;
  
  if (flag<>'' & flag<>'s') then
    flag='';
    warning('Argument ''flag'' not recognised in deg2dms(phi, flag) - ignored.');
  end;
  
  if(size(phi,1)==1) then;
   phi=phi';
  end;
  
  pm  = sign(phi);
  phi = abs(phi);
  dd  = fix(phi);
  mm  = fix((phi-dd)*60);
  ss  = (phi-dd-mm/60)*3600;
  
 
  d   = pm .* (dd + mm/100 + ss/10000);
  dd  = dd.*pm;
  dv  = [dd, mm, ss];
  
  if flag=='s' then
    d = sprintf('%02i°%02i''%02.5f""\n', dd, mm, ss);
  end;

endfunction;