function [state, err] = pars_paramstr(varargin)
// Zerlegt einen Parameterstring vom Type "-param1=value1 -param2=value2 usw."
// in eine Stringmatrix |"-param1" "value1"|.
//
// in : params      - Parameterstring "-param1=value1 -param2=value2 usw."
//      [seperator] - Trennzeichen default=' '
//
// out: param       - Stringmatrix |"-param1" "value1"|
//      err         - Fehlercode [integer] (im Moment immer 0)
//
// (nicht matrixfähig)
// ACHTUNG! Input wird nicht auf sinnhaftigkeit geprüft, -param="test test"
//          ohne schließendes Zeichen (-param="test test) wird nicht
//          als Fehler erkannt
// Copyright (c) area7/Christof Schulze  2009-2010
//--------------------------------------------------------------
//%debug=1

// Ouput variables initialisation (not found in input variables)
state=[]; err=0;

// Number of arguments in function call
  [%nargout,%nargin] = argn(0);
  if (%nargin<1 | %nargin >2) then
    err=58;
    error('a7Core: Wrong number of input arguments:', err);
  else
    if (%nargin==1) then
      params = stripblanks(varargin(1));
      seperator=' ';
    else
      params= stripblanks(varargin(1));
      seperator=varargin(2);
    end;
  end;

//seperate parameters
  // verschiedene Formen von Anführungszeichen auf ' reduzieren
  params2 = strsubst(params, '""', '''');

  begbrac=0;
  spacevec=[];

  for carnr=1:length(params) do
    tst = part(params2,carnr);
    if (tst=="''") then
      if (begbrac==0)
        begbrac = carnr;
      else
        begbrac = 0;
      end;
    end;
    
    if (tst==" ") then
      if (begbrac==0) then
        spacevec = [spacevec, carnr];
      end;
    end;
  end;
  if spacevec<>[] then
    paramsvec = strsplit(params2,spacevec);
  else
    paramsvec = params2;
  end;
  
  //disp(paramsvec);
// seperate parameter name from value
  seplist=[];
  paramslist=list();
  
  for i=1:size(paramsvec,1)
    begbrac=0;
    seplist=[];
    
    for carnr=1:length(paramsvec(i)) do
      tst=part(paramsvec(i),carnr);
      if (tst=="''") then
        if (begbrac==0)
          begbrac = carnr;
        else
          begbrac = 0;
        end;
      end;
      if (tst=="=") then
        if (begbrac==0) then
          //mprintf('gefunden ');
          seplist = [seplist, carnr];
        end;
      end;
    end;
    if seplist==[] then
      error('a7Core : Argument contains no parameterset.'); 
    else
      paramslist(i) = stripblanks(strsplit(paramsvec(i), seplist));
    end;
    
    // '=' von Parameternamen [paramslist(i)(1)] entfernen
    paramslist(i)(1) = stripblanks(strsubst(paramslist(i)(1),'=',''));
    
    // ' von Parameterwert [paramslist(i)(2)] entfernen falls vorhanden
    if (part(paramslist(i)(2), 1)=='''') then
      //mprintf(' .-- gefunden\n');
      paramslist(i)(2) = part(paramslist(i)(2), [2:(length(paramslist(i)(2))-1)] );
    end;
    
    // Parameterpaar in Vektorform bringen
    paramslist(i)=paramslist(i)';
  end;
  
  if (exists('%debug','local')==1) then
    mprintf('\n-- paramsvec\n');
    disp(paramsvec);
    mprintf('-- paramslist\n');
    disp(paramslist);
  end;
  state = paramslist;
  
endfunction;
