function [axis] = plot_fehlerellipse(Pi,Kxx, scale, ID)
// SKYPLOT Polar coordinate plot using azimuth and elevation data.
//
// in : Pi    - Punktkoordinaten [x, y] [deg]
//      Kxx   - Kovarianzmatrix [sig_x, sig_xy; sig_xy, sig_y] []  
//      scale - Mastab, im Vergleich zu der Umgebungsdarstellung (default =1)
//      ID    - Punkt-Nr als [string]
// out: axis  - returns a handle to the axes.
//
// (nicht matrixfhig)
//
// Copyright (c) area7/Christof Schulze  2008
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
  axis=[];

// Number of arguments in function call
  [%nargout,%nargin] = argn(0)

// Display mode
  mode(1);
// Display warning for floating point exception
  ieee(1);

// berprfung der Eingaben
  if %nargin<2 then
    error('Requires 2 or more input arguments.');
    return;
  elseif %nargin==2 then
    scale = 1;
  end;

  if size(Pi)~=[1,2] | size(Kxx)~=[2,2] then
    error('Pi and/or Kxx have wrong size.');
  end;

  if Kxx(1,2)~=Kxx(2,1) then
    error('Wrong definitin of Kxx-matrix?');
    return;
  end;

  sig_xy = Kxx(1,2);
  sig_x2 = Kxx(1,1);
  sig_y2 = Kxx(2,2);
  sig_P  = sum(diag((Kxx)));

  alpha = 0.5 * atan( (2*sig_xy) , (sig_x2 - sig_y2) );     // Winkel der Hauptachse

  R = [ cos(alpha), sin(alpha); -sin(alpha) , cos(alpha)];  // Rotationsmatrix

  Kxnxn = R * Kxx * R';

  mprintf(" Drehwinkel alpha = %f\n", alpha*180/%pi);

  ri = [0:0.05:2*%pi];

  sig_max2 = (sig_x2 + sig_y2) / 2 + 0.5 * sqrt( (sig_x2 - sig_y2)^2 + 4 * sig_xy^2 );
  sig_min2 = (sig_x2 + sig_y2) / 2 - 0.5 * sqrt( (sig_x2 - sig_y2)^2 + 4 * sig_xy^2 );
  sig_max = sqrt(sig_max2); sig_min = sqrt(sig_min2);
  mprintf(" sigma_min = %f \n sigma_max = %f\n\n", sig_min, sig_max);
  mprintf(" Keplert''scher Punktfehler sigma_P = %f\n\n", sig_P);

  sig_r = sqrt( sig_max2 * cos(ri)^2 + sig_min2 * sin(ri)^2 ) * scale;


// Zeichnung erstellen
  //scf();
// Plot der Fupunktskurve
  t = ri + alpha;
  yy = sig_r .* sin(t);
  xx = sig_r .* cos(t);

  plot(xx, yy, 'k-');
  p1=gce();
  p1.children.closed = 'on';
  p1.children.thickness = 1;
  

// Zeichnen der Fehlerellipse
  L = %pi * (1.5 * (sig_max*scale + sig_min*scale) - sqrt(sig_max*scale + sig_min*scale));
  //L = %pi * (1.5 * (sig_max + sig_min) - sqrt(sig_max + sig_min));
  t = linspace(0,L,100*scale);
  xx = [sig_max*scale * cos(t); sig_min*scale * sin(t)]'*R;
  
 
  plot(xx(:,1),xx(:,2), 'k-');
  p2=gce();
  p2.children.thickness = 3;


// Zeichnen der Ellipsen-Achsen

  a = [0,  (sig_min+0.3)*scale ]*R;
  b = [0, -(sig_min+0.3)*scale ]*R;
  l1 = [a;b];
  
  R2 = [ cos(alpha+%pi/2), sin(alpha+%pi/2); -sin(alpha+%pi/2) , cos(alpha+%pi/2)];  // Rotationsmatrix
  b2 = [0, -(sig_max+0.3)*scale ]*R2;
  l2 = [[0, (sig_max+0.3)*scale ]*R2; b2];
  
  plot(l1(:,1), l1(:,2), 'k-.');
  plot(l2(:,1), l2(:,2), 'k-.');

  //xstring(b2(1), b2(2)-0.3, "sigma_max = "+string(sig_max2))
  //xstring(b2(1), b2(2)-0.3, "sigma_max = "+string(sig_max2))
  
  //axis = gca();
  //axis.isoview='on';
endfunction
